@@ -36,9 +36,11 @@ def wf_bandstructure2D(structure, c=None):
     vdw_kernel = c.get("VDW_KERNEL_DIR", VDW_KERNEL_DIR)
     incar = _read_user_incar('Relax2D.txt')
     mpr2d = MPRelaxSet(structure, force_gamma=True, user_incar_settings=incar)
-    fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
-    fws.append(StaticFW2D(parents=fws[0]))
-    fws.append(NonSCFFW2D(parents=fws[1], mode='uniform'))
+    mpr2dstatic = MPRelaxSet(structure, force_gamma=True, user_incar_settings={"NEDOS": "3001", "EMIN": "-15.0", "EMAX": "15.0"})
+    #fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
+    fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, vdw_kernel_dir=vdw_kernel)]
+    fws.append(StaticFW2D(parents=fws[0], vasp_input_set= mpr2dstatic))
+    #fws.append(NonSCFFW2D(parents=fws[1], mode='uniform'))
     fws.append(NonSCFFW2D(parents=fws[1], mode='line'))
     wf = Workflow(fws)
     '''check bandstructure.yaml'''
